| Title: | 'Rcpp' Integration of the 'Streamulus' 'DSEL' for Stream Processing |
|---|---|
| Description: | The 'Streamulus' (template, header-only) library by Irit Katriel (at <https://github.com/iritkatriel/streamulus>) provides a very powerful yet convenient framework for stream processing. This package connects 'Streamulus' to R by providing both the header files and all examples. |
| Authors: | Dirk Eddelbuettel [aut, cre] (ORCID: <https://orcid.org/0000-0001-6419-907X>), Irit Katriel [aut] (Author of 'Streamulus') |
| Maintainer: | Dirk Eddelbuettel <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.1.4 |
| Built: | 2026-05-08 08:56:11 UTC |
| Source: | https://github.com/eddelbuettel/rcppstreams |
This is an example function illustrating Streamulus
commonSubexpressions()commonSubexpressions()
An unconditional TRUE value
Dirk Eddelbuettel
## Not run: commonSubexpressions() ## End(Not run)## Not run: commonSubexpressions() ## End(Not run)
This is an example function illustrating Streamulus
crossAlert(f1, f2)crossAlert(f1, f2)
f1 |
Parameter for the slower exponential moving average |
f2 |
Parameter for the faster exponential moving average |
An unconditional TRUE value
Dirk Eddelbuettel
## Not run: crossAlert(10,20) ## End(Not run)## Not run: crossAlert(10,20) ## End(Not run)
This is an example function illustrating Streamulus
helloStream()helloStream()
An unconditional TRUE value
Dirk Eddelbuettel
## Not run: helloStream() ## End(Not run)## Not run: helloStream() ## End(Not run)
This is an example function illustrating Streamulus
slidingWindow()slidingWindow()
An unconditional TRUE value
Dirk Eddelbuettel
## Not run: slidingWindow() ## End(Not run)## Not run: slidingWindow() ## End(Not run)